@@ -21,8 +21,7 @@
   limitations under the License.
  */
 
-#ifndef _EXPANDING_ARRAY_H_
-#define _EXPANDING_ARRAY_H_
+#pragma once
 
 /****************************************************************************
  *
@@ -39,24 +38,25 @@ class ExpandingArray
 {
 public:
   ExpandingArray(int initialSize, bool freeContents);
-   ~ExpandingArray();
-  void *operator [] (int index);
+  ~ExpandingArray();
+  void *operator[](int index);
   int addEntry(void *entry);
-  void sortWithFunction(int (sortFunc) (const void *, const void *));
-  int getNumEntries()
+  void sortWithFunction(int(sortFunc)(const void *, const void *));
+  int
+  getNumEntries()
   {
     return numValidValues;
   };
   // INTERNAL DataStructure access, use with care
-  void **getArray()
+  void **
+  getArray()
   {
     return internalArray;
   };
+
 private:
   int internalArraySize;
   void **internalArray;
   int numValidValues;
   bool freeContentsOnDestruct;
 };
-
-#endif
