@@ -383,7 +383,7 @@ CacheKey::appendPrefix(const String &prefix, Pattern &prefixCapture, Pattern &pr
   // "true" would mean that the plugin config meant to override the default prefix, "false" means use default.
   bool customPrefix = false;
 
-  /* For all the following operations if a canonical prefix is required then appned to the key with no separator
+  /* For all the following operations if a canonical prefix is required then append to the key with no separator
    * to leave the door open for potential valid host name formed in the final resulting cache key. */
 
   if (!prefix.empty()) {
@@ -673,6 +673,27 @@ CacheKey::appendQuery(const ConfigQuery &config)
   }
 }
 
+void
+CacheKey::appendMatrix(const ConfigMatrix &config)
+{
+  if (config.toBeRemoved()) {
+    return;
+  }
+
+  const char *matrix;
+  int length;
+
+  matrix = TSUrlHttpParamsGet(_buf, _url, &length);
+  if (matrix == nullptr || length == 0) {
+    return;
+  }
+
+  if (matrix && length) {
+    _key.append(";");
+    _key.append(matrix, length);
+  }
+}
+
 /**
  * @brief Append User-Agent header captures specified in the Pattern configuration object.
  *
@@ -753,7 +774,7 @@ CacheKey::finalize() const
   switch (_keyType) {
   case CACHE_KEY: {
     if (TS_SUCCESS == TSCacheUrlSet(_txn, &(_key[0]), _key.size())) {
-      /* Set cache key succesfully */
+      /* Set cache key successfully */
       msg.assign("set cache key to ").append(_key);
       res = true;
     } else {
