@@ -43,15 +43,20 @@ enum OperModifiers {
 class Operator : public Statement
 {
 public:
-  Operator() : _mods(OPER_NONE) { TSDebug(PLUGIN_NAME_DBG, "Calling CTOR for Operator"); }
+  Operator() { TSDebug(PLUGIN_NAME_DBG, "Calling CTOR for Operator"); }
+
+  // noncopyable
+  Operator(const Operator &) = delete;
+  void operator=(const Operator &) = delete;
+
   OperModifiers get_oper_modifiers() const;
-  virtual void initialize(Parser &p);
+  void initialize(Parser &p) override;
 
   void
   do_exec(const Resources &res) const
   {
     exec(res);
-    if (NULL != _next) {
+    if (nullptr != _next) {
       static_cast<Operator *>(_next)->do_exec(res);
     }
   }
@@ -60,9 +65,7 @@ protected:
   virtual void exec(const Resources &res) const = 0;
 
 private:
-  DISALLOW_COPY_AND_ASSIGN(Operator);
-
-  OperModifiers _mods;
+  OperModifiers _mods = OPER_NONE;
 };
 
 ///////////////////////////////////////////////////////////////////////////////
@@ -72,14 +75,16 @@ private:
 class OperatorHeaders : public Operator
 {
 public:
-  OperatorHeaders() : _header("") { TSDebug(PLUGIN_NAME_DBG, "Calling CTOR for OperatorHeaders"); }
-  void initialize(Parser &p);
+  OperatorHeaders() { TSDebug(PLUGIN_NAME_DBG, "Calling CTOR for OperatorHeaders"); }
+
+  // noncopyable
+  OperatorHeaders(const OperatorHeaders &) = delete;
+  void operator=(const OperatorHeaders &) = delete;
+
+  void initialize(Parser &p) override;
 
 protected:
   std::string _header;
-
-private:
-  DISALLOW_COPY_AND_ASSIGN(OperatorHeaders);
 };
 
 ///////////////////////////////////////////////////////////////////////////////
@@ -89,12 +94,14 @@ private:
 class OperatorCookies : public Operator
 {
 public:
-  OperatorCookies() : _cookie("") { TSDebug(PLUGIN_NAME_DBG, "Calling CTOR for OperatorCookies"); }
-  void initialize(Parser &p);
+  OperatorCookies() { TSDebug(PLUGIN_NAME_DBG, "Calling CTOR for OperatorCookies"); }
+
+  // noncopyable
+  OperatorCookies(const OperatorCookies &) = delete;
+  void operator=(const OperatorCookies &) = delete;
+
+  void initialize(Parser &p) override;
 
 protected:
   std::string _cookie;
-
-private:
-  DISALLOW_COPY_AND_ASSIGN(OperatorCookies);
 };
