@@ -83,6 +83,7 @@ enum {
   XHEADER_X_PROBE_HEADERS  = 1u << 9,
   XHEADER_X_PSELECT_KEY    = 1u << 10,
   XHEADER_X_CACHE_INFO     = 1u << 11,
+  XHEADER_X_EFFECTIVE_URL  = 1u << 12,
 };
 
 static TSCont XInjectHeadersCont  = nullptr;
@@ -376,6 +377,29 @@ InjectRemapHeader(TSHttpTxn txn, TSMBuffer buffer, TSMLoc hdr)
   }
 }
 
+static void
+InjectEffectiveURLHeader(TSHttpTxn txn, TSMBuffer buffer, TSMLoc hdr)
+{
+  struct {
+    char *ptr;
+    int len;
+  } strval = {nullptr, 0};
+
+  TSDebug("xdebug", "attempting to inject X-Effective-URL header");
+
+  strval.ptr = TSHttpTxnEffectiveUrlStringGet(txn, &strval.len);
+
+  if (strval.ptr != nullptr && strval.len > 0) {
+    TSMLoc dst = FindOrMakeHdrField(buffer, hdr, "X-Effective-URL", lengthof("X-Effective-URL"));
+    if (dst != TS_NULL_MLOC) {
+      TSReleaseAssert(TSMimeHdrFieldValueStringInsert(buffer, hdr, dst, -1 /* idx */, strval.ptr, strval.len) == TS_SUCCESS);
+      TSHandleMLocRelease(buffer, hdr, dst);
+    }
+  }
+
+  TSfree(strval.ptr);
+}
+
 static void
 InjectOriginalContentTypeHeader(TSHttpTxn txn, TSMBuffer buffer, TSMLoc hdr)
 {
@@ -507,6 +531,10 @@ XInjectResponseHeaders(TSCont /* contp */, TSEvent event, void *edata)
     InjectRemapHeader(txn, buffer, hdr);
   }
 
+  if (xheaders & XHEADER_X_EFFECTIVE_URL) {
+    InjectEffectiveURLHeader(txn, buffer, hdr);
+  }
+
   // intentionally placed after all injected headers.
 
   if (xheaders & XHEADER_X_DUMP_HEADERS) {
@@ -640,7 +668,7 @@ XScanRequestHeaders(TSCont /* contp */, TSEvent event, void *edata)
         TSHttpTxnConfigIntSet(txn, TS_CONFIG_HTTP_INSERT_RESPONSE_VIA_STR, 3);
       } else if (header_field_eq("diags", value, vsize)) {
         // Enable diagnostics for DebugTxn()'s only
-        TSHttpTxnDebugSet(txn, 1);
+        TSHttpTxnCntlSet(txn, TS_HTTP_CNTL_TXN_DEBUG, true);
 
       } else if (header_field_eq("probe", value, vsize)) {
         xheaders |= XHEADER_X_PROBE_HEADERS;
@@ -657,9 +685,9 @@ XScanRequestHeaders(TSCont /* contp */, TSEvent event, void *edata)
         TSHttpTxnHookAdd(txn, TS_HTTP_RESPONSE_TRANSFORM_HOOK, connp);
 
         // disable writing to cache because we are injecting data into the body.
-        TSHttpTxnReqCacheableSet(txn, 0);
-        TSHttpTxnRespCacheableSet(txn, 0);
-        TSHttpTxnServerRespNoStoreSet(txn, 1);
+        TSHttpTxnCntlSet(txn, TS_HTTP_CNTL_RESPONSE_CACHEABLE, false);
+        TSHttpTxnCntlSet(txn, TS_HTTP_CNTL_REQUEST_CACHEABLE, false);
+        TSHttpTxnCntlSet(txn, TS_HTTP_CNTL_SERVER_NO_STORE, true);
         TSHttpTxnTransformedRespCache(txn, 0);
         TSHttpTxnUntransformedRespCache(txn, 0);
 
@@ -673,6 +701,8 @@ XScanRequestHeaders(TSCont /* contp */, TSEvent event, void *edata)
           snprintf(newVal, sizeof(newVal), "fwd=%" PRIiMAX, fwdCnt - 1);
           TSMimeHdrFieldValueStringSet(buffer, hdr, field, i, newVal, std::strlen(newVal));
         }
+      } else if (header_field_eq("x-effective-url", value, vsize)) {
+        xheaders |= XHEADER_X_EFFECTIVE_URL;
       } else {
         TSDebug("xdebug", "ignoring unrecognized debug tag '%.*s'", vsize, value);
       }
