@@ -84,7 +84,7 @@ url_mapping::~url_mapping()
 }
 
 void
-url_mapping::Print()
+url_mapping::Print() const
 {
   char from_url_buf[131072], to_url_buf[131072];
 
@@ -95,6 +95,13 @@ url_mapping::Print()
          _plugin_inst_list.size());
 }
 
+std::string
+url_mapping::PrintRemapHitCount() const
+{
+  std::string result = R"({"fromURL": ")" + remapKey + R"(", "hit_count": )" + std::to_string(_hitCount) + "}";
+  return result;
+}
+
 /**
  *
  **/
