@@ -27,15 +27,14 @@
 
  ***************************************************************************/
 
-#include "ts/ink_platform.h"
-#include "ts/ink_lockfile.h"
-#include "ts/ink_sys_control.h"
-#include "ts/signals.h"
+#include "tscore/ink_platform.h"
+#include "tscore/ink_lockfile.h"
+#include "tscore/ink_sys_control.h"
+#include "tscore/signals.h"
 #include "DiagsConfig.h"
-#include "Main.h"
 
 #include "P_EventSystem.h"
-#include "P_RecProcess.h"
+#include "records/P_RecProcess.h"
 
 #include "ProcessManager.h"
 #include "MgmtUtils.h"
@@ -81,7 +80,7 @@ logging_crash_handler(int signo, siginfo_t *info, void *ptr)
 static void
 init_system(bool notify_syslog)
 {
-  fds_limit = ink_max_out_rlimit(RLIMIT_NOFILE, true, false);
+  fds_limit = ink_max_out_rlimit(RLIMIT_NOFILE);
 
   signal_register_crash_handler(logging_crash_handler);
   if (notify_syslog) {
@@ -99,7 +98,7 @@ initialize_process_manager()
 {
   mgmt_use_syslog();
 
-  // Temporary Hack to Enable Communuication with LocalManager
+  // Temporary Hack to Enable Communication with LocalManager
   if (getenv("PROXY_REMOTE_MGMT")) {
     remote_management_flag = true;
   }
@@ -210,7 +209,6 @@ init_log_standalone(const char *pgm_name, bool one_copy)
   init_system(true);
   initialize_process_manager();
   diagsConfig = new DiagsConfig(pgm_name, logfile, error_tags, action_tags);
-  diags       = diagsConfig->diags;
 }
 
 /*-------------------------------------------------------------------------
@@ -238,7 +236,6 @@ init_log_standalone_basic(const char *pgm_name)
   init_system(false);
   const bool use_records = false;
   diagsConfig            = new DiagsConfig(pgm_name, logfile, error_tags, action_tags, use_records);
-  diags                  = diagsConfig->diags;
   // set stdin/stdout to be unbuffered
   //
   setbuf(stdin, nullptr);
